@@ -28,17 +28,6 @@ if (!console.warn) {
 
 var Gadget = function (options) {
 
-    /* debug */
-    AJS.$.aop.around( {target: gadgets.io, method: 'makeRequest'}, function(invocation) {
-        var url = invocation.arguments[0];
-        if (!/\?/.test(url)) url += "?";
-        else url += "&";
-        invocation.arguments[0] = url + "cacheBuster=" + new Date().getTime();
-        return invocation.proceed();
-    });
-    /* debug end */
-
-
     // private
 
     var
@@ -386,9 +375,7 @@ var Gadget = function (options) {
         resize: function (size) {
             if (gadgets.window.adjustHeight) {
                 gadget.resize.pending = false;
-                window.setTimeout(function () {
-                    gadgets.window.adjustHeight(size);
-                },0);
+                gadgets.window.adjustHeight(size);
             }
         },
 
@@ -641,7 +628,7 @@ var Gadget = function (options) {
                                     AJS.$("#" + window.name + "-chrome", window.top.document).css("opacity", 0.7);
                                 }
                                 gadget.resize();
-                            };
+                            }
                         };
                     }
 
@@ -793,16 +780,14 @@ var Gadget = function (options) {
         var iframeAsContainerHandler = {
             show: function () {
                 if (overflowsIframeHeight() && gadgets.window.adjustHeight) {
-                    gadgets.window.adjustHeight(AJS.$("body").attr("scrollHeight"));
+                    gadget.resize(AJS.$("body").attr("scrollHeight"));
                 }
             },
             hide: function () {
-                window.setTimeout(function() {
-                    if (AJS.$(".active .aui-dropdown").length === 0) {
-                        gadgets.window.adjustHeight(iframeAsContainerHandler.restoreHeight);
-                        delete iframeAsContainerHandler.restoreHeight;
-                    }
-                }, 150);
+                if (AJS.dropDown.current) {
+                    gadget.resize(iframeAsContainerHandler.restoreHeight);
+                    delete iframeAsContainerHandler.restoreHeight;
+                }
             }
         };
 
@@ -884,10 +869,18 @@ var Gadget = function (options) {
 
     })();
 
-
+    // prevent IE from caching requests
+    AJS.$.aop.around( {target: gadgets.io, method: 'makeRequest'}, function(invocation) {
+        var url = invocation.arguments[0];
+        if (!/\?/.test(url)) url += "?";
+        else url += "&";
+        invocation.arguments[0] = url + "cacheBuster=" + new Date().getTime();
+        return invocation.proceed();
+    });
 
     /* set some defaults for ajax requests */
     AJS.$.ajaxSetup({
+        cache: false,
         dataType: "json",
         type: "get",
         baseUrl: options.baseUrl
