@@ -435,7 +435,7 @@ jira.widget.autocomplete = function() {
                 vals = this.field.val().split(delim);
                 // check if the value to append already exists. If it does then call alert to to tell user and sets
                 // the last value to "".
-                if (this.field.val().match(new RegExp(valueToAdd + delim))) {
+                if (!this.allowDuplicates && this.field.val().match(new RegExp(valueToAdd + delim))) {
                     alertUserValueAlreadyExists(valueToAdd);
                     vals[vals.length-1] = "";
                 } else {
@@ -482,12 +482,15 @@ jira.widget.autocomplete = function() {
 
             jQuery.aop.after({target: this, method: "keyUpHandler"}, function(e) {
                 // only initialises once the field length is past set length
-                if ((!(this.field.val().length > this.minQueryLength - 1) || e.keyCode === 27) && this.dropdownController) {
+                if ((!(this.field.val().length > this.minQueryLength - 1) || e.keyCode === 27)
+                        && this.dropdownController && this.dropdownController.displayed) {
                     this.dropdownController.hideDropdown();
+                    if (e.keyCode === 27) {
+                        e.stopPropagation();
+                    }
                 }
                 return e;
             });
-
         },
 
         /**
@@ -804,45 +807,8 @@ jira.widget.autocomplete.Issues = function(options) {
 
 };
 
-AJS.$(function(){
-    AJS.$(".issue-picker-params").each(function(){
-        var params = {};
-        AJS.$(this).find("input").each(function(){
-            var $this = AJS.$(this);
-            params[$this.attr("id")] = $this.val();
-        });
-
-        AJS.$("#" + params.fieldName + "_container a.popup-trigger").click(function(e){
-            var url = contextPath + '/secure/popups/IssuePicker.jspa?';
-            url += 'formName=' + params.formName + '&';
-            url += 'linkFieldName=' + params.fieldName + '&';
-            url += 'currentIssue=' + params.currentIssue + '&';
-            url += 'singleSelectOnly=' + params.singleSelectOnly + '&';
-            url += 'showSubTasks=' + params.showSubTasks + '&';
-            url += 'showSubTasksParent=' + params.showSubTaskParent;
-            if (params.selectedProjectId && params.selectedProjectId != "")
-            {
-                url += '&selectedProjectId=' + params.selectedProjectId;
-            }
-
-            var vWinUsers = window.open(url, 'IssueSelectorPopup', 'status=no,resizable=yes,top=100,left=200,width=620,height=500,scrollbars=yes,resizable');
-            vWinUsers.opener = self;
-            vWinUsers.focus();
-            e.preventDefault();
-        });
-
-        if (params.issuePickerEnabled === "true" ){
-            jira.widget.autocomplete.Issues({
-                fieldID: params.fieldName,
-                delimChar: params.singleSelectOnly === "true"? undefined : ",",
-                ajaxData: params
-            });
-        }
-    });
-});
-
-AJS.$(function(){
-    AJS.$(".user-picker-params").each(function(){
+jira.widget.autocomplete.Users.init = function(parent){
+    AJS.$(".user-picker-params", parent).each(function(){
         var params = {};
         AJS.$(this).find("input").each(function(){
             var $this = AJS.$(this);
@@ -882,7 +848,46 @@ AJS.$(function(){
             });
         }
     });
+};
+jira.widget.autocomplete.Issues.init = function(){
+   AJS.$(".issue-picker-params").each(function(){
+        var params = {};
+        AJS.$(this).find("input").each(function(){
+            var $this = AJS.$(this);
+            params[$this.attr("id")] = $this.val();
+        });
 
+        AJS.$("#" + params.fieldName + "_container a.popup-trigger").click(function(e){
+            var url = contextPath + '/secure/popups/IssuePicker.jspa?';
+            url += 'formName=' + params.formName + '&';
+            url += 'linkFieldName=' + params.fieldName + '&';
+            url += 'currentIssue=' + params.currentIssue + '&';
+            url += 'singleSelectOnly=' + params.singleSelectOnly + '&';
+            url += 'showSubTasks=' + params.showSubTasks + '&';
+            url += 'showSubTasksParent=' + params.showSubTaskParent;
+            if (params.selectedProjectId && params.selectedProjectId != "")
+            {
+                url += '&selectedProjectId=' + params.selectedProjectId;
+            }
+
+            var vWinUsers = window.open(url, 'IssueSelectorPopup', 'status=no,resizable=yes,top=100,left=200,width=620,height=500,scrollbars=yes,resizable');
+            vWinUsers.opener = self;
+            vWinUsers.focus();
+            e.preventDefault();
+        });
+
+        if (params.issuePickerEnabled === "true" ){
+            jira.widget.autocomplete.Issues({
+                fieldID: params.fieldName,
+                delimChar: params.singleSelectOnly === "true"? undefined : ",",
+                ajaxData: params
+            });
+        }
+    });
+};
+AJS.$(function(){
+    jira.widget.autocomplete.Users.init();
+    jira.widget.autocomplete.Issues.init();
 });
 
 AJS.$(function(){
